@@ -53,5 +53,14 @@ assertAccess = function(x, access = "", .var.name) {
 #' @rdname checkAccess
 #' @export
 testAccess = function(x, access = "") {
-  isTRUE(checkAccess(x, access))
+  res = checkAccess(x, access)
+  isTRUE(res)
+}
+
+#' @rdname checkAccess
+#' @template expect
+#' @export
+expect_access = function(x, access = "", info = NULL, label = NULL) {
+  res = checkAccess(x, access)
+  makeExpectation(res, info = info, label = vname(x, label))
 }
