@@ -51,3 +51,12 @@ testAtomicVector = function(x, any.missing = TRUE, all.missing = TRUE, len = NUL
   res = .Call("c_check_atomic_vector", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
   isTRUE(res)
 }
+
+#' @rdname checkAtomicVector
+#' @template expect
+#' @useDynLib checkmate c_check_atomic_vector
+#' @export
+expect_atomic_vector = function(x, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, info = NULL, label = NULL) {
+  res = .Call("c_check_atomic_vector", x, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeExpectation(res, info = info, label = vname(x, label))
+}
