@@ -1,10 +1,11 @@
 #' Check if an argument is an environment
 #'
 #' @templateVar fn Environment
-#' @template checker
+#' @template x
 #' @param contains [\code{character}]\cr
 #'  Vector of object names expected in the environment.
 #'  Defaults to \code{character(0)}.
+#' @template checker
 #' @family basetypes
 #' @export
 #' @examples
@@ -33,5 +34,14 @@ assertEnvironment = function(x, contains = character(0L), .var.name) {
 #' @rdname checkEnvironment
 #' @export
 testEnvironment = function(x, contains = character(0L)) {
-  isTRUE(checkEnvironment(x, contains))
+  res = checkEnvironment(x, contains)
+  isTRUE(res)
+}
+
+#' @rdname checkEnvironment
+#' @template expect
+#' @export
+expect_environment = function(x, contains = character(0L), info = NULL, label = NULL) {
+  res = checkEnvironment(x, contains)
+  makeExpectation(res, info = info, label = vname(x, label))
 }
