@@ -22,6 +22,7 @@
 #' @param names [\code{character(1)}]\cr
 #'  Check for names. See \code{\link{checkNamed}} for possible values.
 #'  Default is \dQuote{any} which performs no check at all.
+#'  Note that you can use \code{\link{checkSubset}} to check for a specific set of names.
 #' @template checker
 #' @family basetypes
 #' @family atomicvector
@@ -48,3 +49,12 @@ testVector = function(x, strict = FALSE, any.missing = TRUE, all.missing = TRUE,
   res = .Call("c_check_vector", x, strict, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
   isTRUE(res)
 }
+
+#' @rdname checkVector
+#' @template expect
+#' @useDynLib checkmate c_check_vector
+#' @export
+expect_vector = function(x, strict = FALSE, any.missing = TRUE, all.missing = TRUE, len = NULL, min.len = NULL, max.len = NULL, unique = FALSE, names = NULL, info = NULL, label = NULL) {
+  res = .Call("c_check_vector", x, strict, any.missing, all.missing, len, min.len, max.len, unique, names, PACKAGE = "checkmate")
+  makeExpectation(res, info = info, label = vname(x, label))
+}
