@@ -11,8 +11,10 @@ makeAssertion = function(msg, var.name) {
 }
 
 makeExpectation = function(res, info, label) {
-  cond = function(tmp) expectation(isTRUE(res), res, "all good")
-  expect_that(1, cond, info = info, label = label)
+  if (!requireNamespace("testthat", quietly = TRUE))
+    stop("Package 'testthat' is required for 'expect_*' extensions")
+  cond = function(tmp) testthat::expectation(isTRUE(res), failure_msg = res, success_msg = "all good")
+  testthat::expect_that(TRUE, cond, info = info, label = label)
 }
 
 mstop = function(msg, ...) {
