@@ -19,6 +19,8 @@
 #' otherwise.
 #' \code{qtest} behaves the same way but returns \code{FALSE} if none of the
 #' \code{rules} comply.
+#' \code{qexpect} is intended to be inside the unit test framework \code{\link[testthat]{testthat}} and
+#' returns an \code{\link[testthat]{expectation}}.
 #'
 #' The rule is specified in up to three parts.
 #' \enumerate{
@@ -97,7 +99,8 @@
 #'
 #' # either an emtpy list or a character vector with <=5 elements
 #' qtest(1, c("l0", "s<=5"))
-#' # data frame with at least one column, no NA in any column
+#'
+#' # data frame with at least one column and no missing value in any column
 #' qtest(iris, "D+")
 qassert = function(x, rules, .var.name) {
   res = .Call("c_qassert", x, rules, FALSE, PACKAGE = "checkmate")
@@ -112,3 +115,12 @@ qassert = function(x, rules, .var.name) {
 qtest = function(x, rules) {
   .Call("c_qtest", x, rules, FALSE, PACKAGE = "checkmate")
 }
+
+#' @useDynLib checkmate c_qassert
+#' @template expect
+#' @rdname qassert
+#' @export
+qexpect = function(x, rules, info = NULL, label = NULL) {
+  res = .Call("c_qassert", x, rules, FALSE, PACKAGE = "checkmate")
+  makeExpectation(res, info = info, label = vname(x, label))
+}
