@@ -2,6 +2,7 @@
 #define CHECKMATE_CMESSAGES_H_
 
 #include <R.h>
+#define USE_RINTERNALS
 #include <Rinternals.h>
 
 enum { CMSGLEN = 256 };
@@ -16,6 +17,5 @@ msg_t make_msg(const char *, ...);
 SEXP make_result(const char *, ...);
 const char * guessType(SEXP);
 SEXP make_type_error(SEXP, const char *);
-SEXP mwrap(msg_t);
 
 #endif
