@@ -1,6 +1,11 @@
 context("checkScalar")
 
 test_that("checkScalar", {
+  myobj = "a"
+  expect_succ_all(Scalar, myobj)
+  myobj = 1:2
+  expect_fail_all(Scalar, myobj)
+
   expect_true(testScalar(TRUE))
   expect_true(testScalar(1L))
   expect_true(testScalar(1))
@@ -8,5 +13,6 @@ test_that("checkScalar", {
   expect_false(testScalar(list(1)))
   expect_false(testScalar(NA, na.ok = FALSE))
   expect_true(testScalar(NA, na.ok = TRUE))
+
   expect_error(assertScalar(integer(0)), "scalar")
 })
